@@ -13,6 +13,6 @@ async def gather(hub, profile: Dict[str, Any]):
         return {
             "attribute_value": acct_details["ret"]["Account"],
             "attribute_key": "Account",
-            "type": "AWS",
+            "provider": "AWS",
         }
     return {}
