@@ -14,8 +14,6 @@ def parse(hub, session: "boto3.session.Session", service: str):
     # Create the boto client that will be parsed for capabilities
     client = session.client(
         service_name=service,
-        region_name=hub.OPT.pop_create.region,
-        api_version=hub.OPT.pop_create.api_version,
     )
     operations = {}
     for op in client.meta.method_to_api_mapping:
@@ -23,6 +21,9 @@ def parse(hub, session: "boto3.session.Session", service: str):
             verb, resource = op.split("_", maxsplit=1)
             if re.match(rf"\w+[^aoius]s$", resource):
                 resource = hub.tool.format.inflect.singular(resource)
+            # Special case for resource names that end with apis
+            if resource.endswith("apis"):
+                resource = resource[:-1]
             if resource not in operations:
                 operations[resource] = {}
             operations[resource][verb] = op
@@ -34,8 +35,6 @@ def parse(hub, session: "boto3.session.Session", service: str):
     try:
         service_resource = session.resource(
             service_name=service,
-            region_name=hub.OPT.pop_create.region,
-            api_version=hub.OPT.pop_create.api_version,
         )
         for sub_resource in service_resource.meta.resource_model.subresources:
             resources[hub.tool.format.case.snake(sub_resource.name)] = (
@@ -83,7 +82,9 @@ def parse(hub, session: "boto3.session.Session", service: str):
                 hub.log.info(
                     f"Cannot determine how to describe {clean_service}.{resource}: {list(functions.keys())}"
                 )
-                continue
+                describe_function_call = (
+                    "await hub.tool.boto3.resource.describe(resource)"
+                )
         else:
             # If the client wasn't complete, try to use a resource
             r = resources[resource]
@@ -92,37 +93,40 @@ def parse(hub, session: "boto3.session.Session", service: str):
             describe_function_call = "await hub.tool.boto3.resource.describe(resource)"
             other_calls.extend(r[1])
 
+        state_functions = {}
+
         # Get create function
         for func_name in hub.pop_create.aws.template.CREATE_FUNCTIONS:
             if func_name in functions:
-                create_function = functions[func_name]
+                state_functions["present"] = functions[func_name]
                 break
         else:
             hub.log.info(
                 f"Cannot determine how to create {clean_service}.{resource}: {list(functions.keys())}"
             )
-            continue
 
         # Get delete function
         for func_name in hub.pop_create.aws.template.DELETE_FUNCTIONS:
             if func_name in functions:
-                delete_function = functions[func_name]
+                state_functions["absent"] = functions[func_name]
                 break
         else:
             hub.log.info(
                 f"Cannot determine how to delete {clean_service}.{resource}: {list(functions.keys())}"
             )
-            continue
 
         # Get list function
         for func_name in functions:
             if client.can_paginate(functions[func_name]):
-                list_function = functions[func_name]
+                state_functions["describe"] = functions[func_name]
                 break
         else:
             hub.log.info(
                 f"Cannot determine how to describe {clean_service}.{resource}: {list(functions.keys())}"
             )
+
+        # Skip resource if present function cannot be determined
+        if not state_functions.get("present", None):
             continue
 
         clean_resource = hub.tool.format.keyword.unclash(resource)
@@ -130,6 +134,8 @@ def parse(hub, session: "boto3.session.Session", service: str):
         plugins[plugin_key] = {
             "imports": [
                 "import copy",
+                "from dataclasses import field",
+                "from dataclasses import make_dataclass",
                 "from typing import *",
                 "__contracts__ = ['resource']",
             ],
@@ -141,9 +147,9 @@ def parse(hub, session: "boto3.session.Session", service: str):
 
         plugins[plugin_key]["doc"] = "\n".join(other_calls)
         shared_function_data = {
-            "delete_function": f"hub.exec.boto3.client.{clean_service}.{delete_function}",
-            "create_function": f"hub.exec.boto3.client.{clean_service}.{create_function}",
-            "list_function": f"hub.exec.boto3.client.{clean_service}.{list_function}",
+            "delete_function": f"hub.exec.boto3.client.{clean_service}.{state_functions.get('absent', 'delete_function')}",
+            "create_function": f"hub.exec.boto3.client.{clean_service}.{state_functions.get('present', 'create_function')}",
+            "list_function": f"hub.exec.boto3.client.{clean_service}.{state_functions.get('describe', 'list_function')}",
             "waiter_call": "",
             "resource_function_call": get_resource_call,
             "describe_function_call": describe_function_call,
@@ -155,13 +161,18 @@ def parse(hub, session: "boto3.session.Session", service: str):
             "is_idempotent": False,
             "tag_method": "TODO, unify the way resources are tagged",
         }
-        for state_function, op_name in zip(
-            ("present", "absent", "describe"),
-            (create_function, delete_function, list_function),
-        ):
-            func_definition = hub.pop_create.aws.function.parse(
-                client, service, op_name
-            )
+        for state_function in ["present", "absent", "describe"]:
+            if not state_functions.get(state_function, None):
+                func_definition = {
+                    "doc": "Missing function",
+                    "params": {},
+                    "return_type": None,
+                    "hardcoded": {},
+                }
+            else:
+                func_definition = hub.pop_create.aws.function.parse(
+                    client, service, state_functions[state_function]
+                )
             func_definition["hardcoded"].update(shared_function_data)
             func_definition["hardcoded"].update(
                 {
