@@ -1,25 +1,12 @@
 CLI_CONFIG = {
-    "api_version": {"subcommands": ["aws"], "dyne": "pop_create"},
-    "region": {
-        "subcommands": ["aws"],
-        "dyne": "pop_create",
-    },
+    # pop-create options
     "services": {
         "subcommands": ["aws"],
         "dyne": "pop_create",
     },
 }
 CONFIG = {
-    "api_version": {
-        "default": None,
-        "help": "The cloud api version to target",
-        "dyne": "pop_create",
-    },
-    "region": {
-        "default": "us-west-2",
-        "help": "The cloud region to target",
-        "dyne": "pop_create",
-    },
+    # pop-create options
     "services": {
         "default": [],
         "nargs": "*",
