@@ -9,14 +9,14 @@ Exec functions for AWS DynamoDB Table resources.
 
 
 async def get(hub, ctx, name, resource_id) -> Dict[str, Any]:
-    r"""
-    Get a DynamoDB Table resource from AWS.
+    r"""Get a DynamoDB Table resource from AWS.
 
     Args:
-        hub: required for functions in hub.
-        ctx: context.
-        name(string): The name of the Idem state.
-        resource_id(string): The name of the Dynamodb table.
+        name(str):
+            The name of the Idem state.
+
+        resource_id(str):
+            The name of the Dynamodb table.
 
     Returns:
         Dict[str, Any]
