@@ -35,32 +35,54 @@ async def bootstrap(
     verify: bool = True,
     **kwargs,
 ):
-    """
-    Connect to the instance with an ssh keypair and call heist to bootstrap it.
+    """Connect to the instance with an ssh keypair and call heist to bootstrap it.
+
     If an ssh keypair is not provided one will be created.
 
     Args:
-        hub:
-        ctx:
-        instance_id: An AWS EC2 Instance ID
-        username(Text, Optional): The instance OS username to use in the connection, Defaults to ec2-user
-        host(Text, Optional): The public ip address or dns name of the instance.  Defaults to autodetect
-        port(int, Optional): The port to connect to on the host.  Defaults to 22.
-        ssh_public_key(Text, Optional): A public ssh key or path to send to the instance
-        ssh_private_key(Text, Optional): A private ssh key or path to send to the instance
-        availability_zone(Text, Optional): The Availability Zone in which the EC2 instance was launched
-        heist_manager(Text, Required): The heist manager to use to bootstrap the instance (I.E. salt.minion)
-        artifact_version(Text, Optional): The version of the heist_manager's artifact to upload to the instance, Defaults to latest
-        tunnel_plugin(Text, Optional): The heist tunnel plugin to use to ssh into the instance. Defaults to asyncssh
-        auto_configure(Bool, Optional): automatically apply internet_gateway/subnet/vpc/route_table changes needed to SSH into an instance
-        verify(bool, Optional): If set to True, then verify that the instance is prepared for ssh connections
-        kwargs: All extra kwargs are used in asyncssh.SSHClientConnectionOptions
+        instance_id:
+            An AWS EC2 Instance ID.
+
+        username(str, Optional):
+            The instance OS username to use in the connection, Defaults to ec2-user.
+
+        host(str, Optional):
+            The public ip address or dns name of the instance.  Defaults to autodetect.
+
+        port(int, Optional):
+            The port to connect to on the host.  Defaults to 22.
+
+        ssh_public_key(str, Optional):
+            A public ssh key or path to send to the instance.
+
+        ssh_private_key(str, Optional):
+            A private ssh key or path to send to the instance.
+
+        availability_zone(str, Optional):
+            The Availability Zone in which the EC2 instance was launched.
+
+        heist_manager(str, Required):
+            The heist manager to use to bootstrap the instance (I.E. salt.minion).
+
+        artifact_version(str, Optional):
+            The version of the heist_manager's artifact to upload to the instance, Defaults to latest.
+
+        tunnel_plugin(str, Optional):
+            The heist tunnel plugin to use to ssh into the instance. Defaults to asyncssh.
+
+        auto_configure(Bool, Optional):
+            automatically apply internet_gateway/subnet/vpc/route_table changes needed to SSH into an instance.
+
+        verify(bool, Optional):
+            If set to True, then verify that the instance is prepared for ssh connections.
+
+        kwargs:
+            All extra kwargs are used in asyncssh.SSHClientConnectionOptions.
 
     Returns:
         {"result": True|False, "comment": A message Tuple, "ret": Dict}
 
     Examples:
-
         .. code-block:: bash
 
             idem exec aws.ec2.instance.bootstrap <instance_id> heist_manager="salt.minion"
@@ -114,14 +136,14 @@ async def bootstrap(
 
 
 async def verify_ssh(hub, ctx, instance_id: str, auto_configure: bool = False):
-    """
-    Verify that an instance meets all the requirements for SSH connection
+    """Verify that an instance meets all the requirements for SSH connection
 
     Args:
-        hub:
-        ctx:
-        instance_id: An AWS EC2 Instance ID
-        auto_configure: automatically apply internet_gateway/subnet/vpc/route_table changes needed to SSH into an instance
+        instance_id(str):
+            An AWS EC2 Instance ID.
+
+        auto_configure(bool, Optional):
+            Automatically apply internet_gateway/subnet/vpc/route_table changes needed to SSH into an instance.
 
     Returns:
         {"result": True|False, "comment": A message Tuple, "ret": Dict}
@@ -271,28 +293,42 @@ async def connect(
     availability_zone: str = None,
     **kwargs,
 ):
-    """
-    Attempt connection with SSH to the instance with the given parameters.
+    """Attempt connection with SSH to the instance with the given parameters.
+
     If no host or username is specified, then make reasonable guesses and return the target configuration that was successful
 
     Args:
-        hub:
-        ctx:
-        instance_id: An AWS EC2 Instance ID
-        username(Text, Optional): The instance OS username to use in the connection, Defaults to ec2-user
-        host(Text, Optional): The public ip address or dns name of the instance.  Defaults to autodetect
-        port(int, Optional): The port to connect to on the host.  Defaults to 22.
-        ssh_public_key(Text, Optional): A public ssh key or path to send to the instance
-        private_key_file(Text, Optional): The path to a private ssh key file
-        availability_zone(Text, Optional): The Availability Zone in which the EC2 instance was launched
-        tunnel_plugin(Text, Optional): The heist tunnel plugin to use to ssh into the instance. Defaults to asyncssh
-        kwargs: All extra kwargs are used in asyncssh.SSHClientConnectionOptions
+        instance_id(str):
+            An AWS EC2 Instance ID.
+
+        username(str, Optional):
+            The instance OS username to use in the connection, Defaults to ec2-user.
+
+        host(str, Optional):
+            The public ip address or dns name of the instance.  Defaults to autodetect.
+
+        port(int, Optional):
+            The port to connect to on the host.  Defaults to 22.
+
+        ssh_public_key(str, Optional):
+            A public ssh key or path to send to the instance.
+
+        private_key_file(str, Optional):
+            The path to a private ssh key file.
+
+        availability_zone(str, Optional):
+            The Availability Zone in which the EC2 instance was launched.
+
+        tunnel_plugin(str, Optional):
+            The heist tunnel plugin to use to ssh into the instance. Defaults to asyncssh.
+
+        kwargs:
+            All extra kwargs are used in asyncssh.SSHClientConnectionOptions.
 
     Returns:
         {"result": True|False, "comment": A message Tuple, "ret": Dict}
 
     Examples:
-
         .. code-block:: bash
 
             idem exec aws.ec2.instance.connect <instance_id>
@@ -423,7 +459,7 @@ async def start(hub, ctx, instance_id: str):
 
 async def stop(hub, ctx, instance_id: str):
     """
-    Stop the instance and wait for it to be stopped
+    Stop the instance and wait for it to be stopped.
     """
     result = dict(result=True, comment=[], ret={})
 
@@ -451,12 +487,15 @@ async def get(
 ) -> Dict:
     """
     Args:
-        hub:
-        ctx:
-        name(string): The name of the Idem state.
-        resource_id(string, optional): AWS VPC id to identify the resource.
-        filters(list, optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
-         https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_instances
+        name(str):
+            The name of the Idem state.
+
+        resource_id(str, Optional):
+            AWS VPC id to identify the resource.
+
+        filters(list, Optional):
+            One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
+            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_instances.
     """
     result = dict(comment=[], ret=None, result=True)
     if resource_id:
@@ -497,11 +536,12 @@ async def get(
 async def list_(hub, ctx, *, name=None, filters: List = None) -> Dict:
     """
     Args:
-        hub:
-        ctx:
-        name(string): The name of the Idem state.
-        filters(list, optional): One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
-         https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_instances
+        name(str):
+            The name of the Idem state.
+
+        filters(list, Optional):
+            One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
+            https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_instances.
     """
     result = dict(comment=[], ret=[], result=True)
     ret = await hub.exec.boto3.client.ec2.describe_instances(
