@@ -1,6 +1,8 @@
+import copy
 from typing import Any
 from typing import Dict
 
+from dict_tools import data
 from dict_tools import differ
 
 
@@ -33,10 +35,19 @@ async def update_options(
 
     """
     result = dict(comment=(), result=True, ret=None)
-    diff_in_options = differ.deep_diff(old_options, new_options)
-    if old_description == new_description and (
-        not diff_in_options or new_options is None
-    ):
+    resolved_new_options = copy.deepcopy(old_options)
+
+    for key in new_options.keys():
+        resolved_new_options[key] = new_options[key]
+
+    # compare option
+    diff_in_options = data.recursive_diff(
+        old_options,
+        resolved_new_options,
+        ignore_order=True,
+    )
+
+    if old_description == new_description and (not diff_in_options):
         result["comment"] = (f"no changes to update {transit_gateway_id}",)
         return result
     modify_options = None
