@@ -9,8 +9,8 @@ async def update_tags(
     ctx,
     resource_id: str,
     resource_type: str,
-    old_tags: List[Dict[str, Any]] = None,
-    new_tags: List[Dict[str, Any]] = None,
+    old_tags: List[Dict[str, Any]] or Dict[str, Any] = None,
+    new_tags: List[Dict[str, Any]] or Dict[str, Any] = None,
 ):
     """
     Update tags of AWS route53 hosted zone resources
@@ -19,37 +19,29 @@ async def update_tags(
         ctx:
         resource_id (Text): route53 hosted_zone resource id
         resource_type (Text): type of resource,
-        old_tags (List): list of old tags
-        new_tags (List): list of new tags
+        old_tags (List): list of old tags in the format of [{"Key": tag-key, "Value": tag-value}] or dict in the format of
+                         {tag-key: tag-value}
+        new_tags (List): list of new tags in the format of [{"Key": tag-key, "Value": tag-value}] or dict in the format of
+                         {tag-key: tag-value}
 
     Returns:
         {"result": True|False, "comment": ("A message",), "ret": Dict}
 
     """
-    tags_to_add = []
-    tags_to_remove = []
-    if old_tags is None:
-        tags_to_remove = None
-        tags_to_add = new_tags
-        tags_result = {}
-    else:
-        old_tags_map = {tag.get("Key"): tag for tag in old_tags}
-        tags_result = copy.deepcopy(old_tags_map)
-        if new_tags is not None:
-            for tag in new_tags:
-                if tag.get("Key") in old_tags_map:
-                    if tag.get("Value") == old_tags_map.get(tag.get("Key")).get(
-                        "Value"
-                    ):
-                        del old_tags_map[tag.get("Key")]
-                    else:
-                        tags_to_add.append(tag)
-                else:
-                    tags_to_add.append(tag)
-            tags_to_remove = [tag.get("Key") for tag in old_tags_map.values()]
-    result = dict(comment=(), result=True, ret=None)
 
+    tags_to_add = {}
+    tags_to_remove = {}
+    if isinstance(old_tags, List):
+        old_tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict(old_tags)
+    if isinstance(new_tags, List):
+        new_tags = hub.tool.aws.tag_utils.convert_tag_list_to_dict(new_tags)
+    if new_tags is not None:
+        tags_to_remove, tags_to_add = hub.tool.aws.tag_utils.diff_tags_dict(
+            old_tags=old_tags, new_tags=new_tags
+        )
+    result = dict(comment=(), result=True, ret={})
     if (not tags_to_remove) and (not tags_to_add):
+        result["ret"] = copy.deepcopy(old_tags if old_tags else {})
         return result
     elif not tags_to_remove:
         tags_to_remove = None
@@ -60,8 +52,8 @@ async def update_tags(
             ctx,
             ResourceType=resource_type,
             ResourceId=resource_id,
-            AddTags=tags_to_add,
-            RemoveTagKeys=tags_to_remove,
+            AddTags=hub.tool.aws.tag_utils.convert_tag_dict_to_list(tags_to_add),
+            RemoveTagKeys=list(tags_to_remove) if tags_to_remove else None,
         )
         if not change_tag_resp["result"]:
             response_message = change_tag_resp["comment"]
@@ -75,6 +67,6 @@ async def update_tags(
             return result
         hub.log.debug(f"modified tags for {resource_id}")
 
-    result["ret"] = {"tags": list(tags_result.values()) + tags_to_add}
+    result["ret"] = new_tags
     result["comment"] = (f"Update tags: Add [{tags_to_add}] Remove [{tags_to_remove}]",)
     return result
