@@ -43,19 +43,19 @@ async def present(
             Constraints: 3-128 alphanumeric characters, parentheses (``()``), square brackets (``[]``), spaces, periods (``.``),
             slashes (``/``), dashes (``-``), single quotes (``'``), at-signs (``@``), or underscores(``_``)
 
-        resource_id(str, optional):
+        resource_id(str, Optional):
             AWS AMI image_id
 
-        image_location(str, optional):
+        image_location(str, Optional):
             The full path to your AMI manifest in Amazon S3 storage.
             The specified bucket must have the aws-exec-read canned access control list (ACL) to ensure that it can be accessed by Amazon EC2.
             For more information, see Canned ACLs in the Amazon S3 Service Developer Guide .
 
-        architecture(str, optional):
+        architecture(str, Optional):
             The architecture of the AMI. Default: For Amazon EBS-backed AMIs, i386.
             For instance store-backed AMIs, the architecture specified in the manifest file.
 
-        block_device_mappings(list, optional):
+        block_device_mappings(list, Optional):
             The block device mapping entries.
             If you specify an Amazon EBS volume using the ID of an Amazon EBS snapshot, you can't specify the encryption state of the volume.
             If you create an AMI on an Outpost, then all backing snapshots must be on the same Outpost or in the Region of that Outpost.
@@ -80,11 +80,11 @@ async def present(
             * Ebs (dict):
                 Parameters used to automatically set up EBS volumes when the instance is launched.
 
-            * DeleteOnTermination (bool, optional):
+            * DeleteOnTermination (bool, Optional):
                 Indicates whether the EBS volume is deleted on instance termination. For more information,
                 see Preserving Amazon EBS volumes on instance termination in the Amazon EC2 User Guide .
 
-            * Iops (int, optional):
+            * Iops (int, Optional):
                 The number of I/O operations per second (IOPS). For gp3 , io1 , and io2 volumes,
                 this represents the number of IOPS that are provisioned for the volume. For gp2 volumes,
                 this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.
@@ -119,19 +119,19 @@ async def present(
                 The volume type. For more information, see Amazon EBS volume types in the Amazon EC2 User Guide .
                 If the volume type is io1 or io2 , you must specify the IOPS that the volume supports.
 
-            * KmsKeyId (str, optional):
+            * KmsKeyId (str, Optional):
                 Identifier (key ID, key alias, ID ARN, or alias ARN) for a customer managed CMK under which the EBS volume is encrypted.
                 This parameter is only supported on BlockDeviceMapping objects called by RunInstances, RequestSpotFleet, and RequestSpotInstances .
 
-            * Throughput (int, optional):
+            * Throughput (int, Optional):
                 The throughput that the volume supports, in MiB/s.
                 This parameter is valid only for gp3 volumes.
                 Valid Range: Minimum value of 125. Maximum value of 1000.
 
-            * OutpostArn (str, optional):
+            * OutpostArn (str, Optional):
                 The ARN of the Outpost on which the snapshot is stored.
 
-            * Encrypted (bool, optional):
+            * Encrypted (bool, Optional):
                 Indicates whether the encryption state of an EBS volume is changed while being restored from a backing snapshot.
                 The effect of setting the encryption state to true depends on the volume origin (new or from a snapshot),
                 starting encryption state, ownership, and whether encryption by default is enabled. For more information,
@@ -141,44 +141,44 @@ async def present(
                 For more information, see Supported instance types .
                 This parameter is not returned by DescribeImageAttribute .
 
-            * NoDevice (str, optional):
+            * NoDevice (str, Optional):
                 To omit the device from the block device mapping, specify an empty string.
                 When this property is specified, the device is removed from the block device mapping regardless of the assigned value.
 
-        description(str, optional):
+        description(str, Optional):
             A description for your AMI.
 
-        ena_support(bool, optional):
+        ena_support(bool, Optional):
             Set to true to enable enhanced networking with ENA for the AMI and any instances that you launch from the AMI.
             This option is supported only for HVM AMIs.
             Specifying this option with a PV AMI can make instances launched from the AMI unreachable.
 
-        kernel_id (str, optional):
+        kernel_id (str, Optional):
             The ID of the kernel.
 
-        billing_products (list, optional):
+        billing_products (list, Optional):
             The billing product codes. Your account must be authorized to specify billing product codes.
             Otherwise, you can use the Amazon Web Services Marketplace to bill for the use of an AMI.
 
-        ramdisk_id(str, optional):
+        ramdisk_id(str, Optional):
             The ID of the RAM disk.
 
-        root_device_name(str, optional):
+        root_device_name(str, Optional):
             The device name of the root device volume (for example, /dev/sda1 ).
 
-        sriov_net_support(str, optional):
+        sriov_net_support(str, Optional):
             Set to simple to enable enhanced networking with the Intel 82599 Virtual Function interface for the AMI and any instances that you launch from the AMI.
             There is no way to disable sriovNetSupport at this time.
             This option is supported only for HVM AMIs. Specifying this option with a PV AMI can make instances launched from the AMI unreachable.
 
-        virtualization_type(str, optional):
+        virtualization_type(str, Optional):
             The type of virtualization (hvm | paravirtual).
             Default: paravirtual
 
-        boot_mode(str, optional):
+        boot_mode(str, Optional):
             The boot mode of the AMI. For more information, see Boot modes in the Amazon Elastic Compute Cloud User Guide.
 
-        tags(dict or list, optional):
+        tags(dict or list, Optional):
             Dict in the format of ``{tag-key: tag-value}`` or List of tags in the format of
             ``[{"Key": tag-key, "Value": tag-value}]`` to associate with the AMI.
 
@@ -304,23 +304,18 @@ async def present(
     }
 
     if resource_id:
-        response = await hub.exec.boto3.client.ec2.describe_images(
-            ctx, ImageIds=[resource_id]
+        response = await hub.exec.aws.ec2.ami.get(
+            ctx, name=name, resource_id=resource_id
         )
         if not response["result"]:
             result["comment"] = response["comment"]
             result["result"] = response["result"]
             return result
-        if response["ret"].get("Images"):
-            before = response["ret"].get("Images")[0]
+        if response["ret"]:
+            before = response["ret"]
 
     if before:
-
-        result[
-            "old_state"
-        ] = hub.tool.aws.ec2.conversion_utils.convert_raw_ami_to_present(
-            raw_resource=before
-        )
+        result["old_state"] = copy.deepcopy(before)
         plan_state = copy.deepcopy(result["old_state"])
 
         # update (we can only update tags and description)
@@ -408,15 +403,11 @@ async def present(
         if ctx.get("test", False):
             result["new_state"] = plan_state
         elif (not before) or resource_updated:
-            response = await hub.exec.boto3.client.ec2.describe_images(
-                ctx, ImageIds=[resource_id]
-            )
-            after = response["ret"].get("Images")[0]
-            result[
-                "new_state"
-            ] = hub.tool.aws.ec2.conversion_utils.convert_raw_ami_to_present(
-                raw_resource=after
+            response = await hub.exec.aws.ec2.ami.get(
+                ctx, name=name, resource_id=resource_id
             )
+            after = response["ret"]
+            result["new_state"] = copy.deepcopy(after)
         else:
             result["comment"] = (f"aws.ec2.ami '{name}' already exists",)
             result["new_state"] = copy.deepcopy(result["old_state"])
@@ -446,7 +437,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
     Args:
         name(str): The Idem name of the AMI.
-        resource_id(str, optional): The AWS image_id.
+        resource_id(str, Optional): The AWS image_id.
 
     Request Syntax:
         .. code-block:: sls
@@ -472,23 +463,17 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
         result["comment"] = (f"aws.ec2.ami '{name}' already absent",)
         return result
 
-    before = await hub.exec.boto3.client.ec2.describe_images(
-        ctx, ImageIds=[resource_id]
-    )
+    before = await hub.exec.aws.ec2.ami.get(ctx, name=name, resource_id=resource_id)
 
     if not before["result"]:
         result["comment"] = before["comment"]
         result["result"] = False
         return result
 
-    if not before["ret"].get("Images"):
+    if not before["ret"]:
         result["comment"] = (f"aws.ec2.ami '{name}' already absent",)
     else:
-        result[
-            "old_state"
-        ] = hub.tool.aws.ec2.conversion_utils.convert_raw_ami_to_present(
-            raw_resource=before["ret"].get("Images")[0]
-        )
+        result["old_state"] = copy.deepcopy(before["ret"])
 
         if ctx.get("test", False):
             result["comment"] = (f"Would delete aws.ec2.ami '{name}'",)
@@ -560,26 +545,26 @@ async def search(
         name(str):
             The name of the Idem state.
 
-        resource_id(str, optional):
+        resource_id(str, Optional):
             AWS image id to identify the resource.
 
-        executable_users(list, optional):
+        executable_users(list, Optional):
             Scopes the images by users with explicit launch permissions.
             Specify an Amazon Web Services account ID, self (the sender of the request), or all (public AMIs).
 
-        owners(list, optional):
+        owners(list, Optional):
             Scopes the results to images with the specified owners.
             You can specify a combination of Amazon Web Services account IDs, self , amazon , and aws-marketplace.
             If you omit this parameter, the results include all images for which you have launch permissions, regardless of ownership.
 
-        include_deprecated(bool, optional):
+        include_deprecated(bool, Optional):
             If true , all deprecated AMIs are included in the response.
             If false , no deprecated AMIs are included in the response. If no value is specified, the default value is false .
 
-        most_recent(bool, optional):
+        most_recent(bool, Optional):
             If more than one result is returned, use the most recent AMI.
 
-        filters(list, optional):
+        filters(list, Optional):
             One or more filters: for example, tag :<key>, tag-key. A complete list of filters can be found at
             `boto3: EC2.Client.describe_images <https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Client.describe_images>`__
 
