@@ -440,6 +440,7 @@ async def search(
 ):
     """
     Use an un-managed hosted_zone as a data-source. Supply one or more of the inputs as the filter.
+    This function has been deprecated. Please use exec.run with aws.route53.hosted_zone.get instead.
 
     Args:
         name(string): The name of the Idem state.
@@ -495,15 +496,9 @@ async def search(
         result["comment"] = (
             f"Found hosted_zone with given resource_id {resource_id}, other filters will not be considered",
         )
-        hosted_zone = ret
-        tags_ret = await hub.exec.boto3.client.route53.list_tags_for_resource(
-            ctx, ResourceType="hostedzone", ResourceId=resource_id
-        )
-        if not tags_ret["result"]:
-            result["comment"] = tags_ret["comment"]
-            result["result"] = False
-            return result
-        tags = tags_ret["ret"]["ResourceTagSet"].get("Tags")
+        result["old_state"] = ret["ret"]
+        # Populate both "old_state" and "new_state" with the same data
+        result["new_state"] = copy.deepcopy(result["old_state"])
     else:
         # Get all the hosted_zones to apply the filters
         describe_ret = (
@@ -532,14 +527,14 @@ async def search(
         hosted_zone = ret["ret"][0]
         tags = hosted_zone.get("tags")
 
-    result[
-        "old_state"
-    ] = hub.tool.aws.route53.conversion_utils.convert_raw_hosted_zone_to_present(
-        raw_resource=hosted_zone,
-        idem_resource_name=name,
-        tags=tags,
-    )
-    # Populate both "old_state" and "new_state" with the same data
-    result["new_state"] = copy.deepcopy(result["old_state"])
+        result[
+            "old_state"
+        ] = hub.tool.aws.route53.conversion_utils.convert_raw_hosted_zone_to_present(
+            raw_resource=hosted_zone,
+            idem_resource_name=name,
+            tags=tags,
+        )
+        # Populate both "old_state" and "new_state" with the same data
+        result["new_state"] = copy.deepcopy(result["old_state"])
 
     return result
