@@ -1,10 +1,12 @@
 from collections import OrderedDict
+from datetime import timezone
 from typing import Any
 from typing import Dict
 
 """
 Util functions to convert raw resource state from AWS EC2 to present input format.
 """
+UTC_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
 
 
 async def convert_raw_vpc_to_present(
@@ -608,6 +610,7 @@ def convert_raw_ami_to_present(hub, raw_resource: Dict[str, Any]) -> Dict[str, A
     resource_parameters = OrderedDict(
         {
             "Name": "name",
+            "CreationDate": "creation_date",
             "ImageLocation": "image_location",
             "Architecture": "architecture",
             "KernelId": "kernel_id",
@@ -719,7 +722,16 @@ async def convert_raw_snapshot_to_present(
         )
 
     if volume["result"] and volume["ret"]:
-        resource_translated["associated_volume"] = volume["ret"]
+        translated_volume = {}
+        for prop in volume["ret"]:
+            if prop != "tags":
+                translated_volume[prop] = volume["ret"].get(prop)
+        resource_translated["associated_volume"] = translated_volume
+
+    if "StartTime" in raw_resource:
+        local_time = raw_resource.get("StartTime").astimezone()
+        start_time = local_time.astimezone(timezone.utc).strftime(UTC_FORMAT)
+        resource_translated["start_time"] = start_time
 
     if "Tags" in raw_resource:
         resource_translated["tags"] = hub.tool.aws.tag_utils.convert_tag_list_to_dict(
@@ -761,3 +773,35 @@ def convert_raw_volume_to_present(
             raw_resource.get("Tags")
         )
     return resource_translated
+
+
+def convert_raw_vpc_peering_connection_options_to_present(
+    hub, raw_resource: Dict[str, Any], idem_resource_name: str
+) -> Dict[str, Any]:
+    if not raw_resource:
+        return {}
+
+    resource_translated = {
+        "resource_id": raw_resource["VpcPeeringConnectionId"],
+        "name": idem_resource_name,
+        "peer_allow_remote_vpc_dns_resolution": raw_resource["AccepterVpcInfo"][
+            "PeeringOptions"
+        ]["AllowDnsResolutionFromRemoteVpc"],
+        "peer_allow_classic_link_to_remote_vpc": raw_resource["AccepterVpcInfo"][
+            "PeeringOptions"
+        ]["AllowEgressFromLocalClassicLinkToRemoteVpc"],
+        "peer_allow_vpc_to_remote_classic_link": raw_resource["AccepterVpcInfo"][
+            "PeeringOptions"
+        ]["AllowEgressFromLocalVpcToRemoteClassicLink"],
+        "allow_remote_vpc_dns_resolution": raw_resource["RequesterVpcInfo"][
+            "PeeringOptions"
+        ]["AllowDnsResolutionFromRemoteVpc"],
+        "allow_classic_link_to_remote_vpc": raw_resource["RequesterVpcInfo"][
+            "PeeringOptions"
+        ]["AllowEgressFromLocalClassicLinkToRemoteVpc"],
+        "allow_vpc_to_remote_classic_link": raw_resource["RequesterVpcInfo"][
+            "PeeringOptions"
+        ]["AllowEgressFromLocalVpcToRemoteClassicLink"],
+    }
+
+    return resource_translated
