@@ -32,6 +32,39 @@ def convert_raw_web_acl_resource_association_to_present(
     return translated_resource
 
 
+def convert_raw_regex_pattern_set_to_present(
+    hub, ctx, raw_resource: Dict[str, Any], scope: str, tags: Dict[str, str]
+) -> Dict[str, Any]:
+    """
+    Util functions to convert raw resource state from regex pattern state to present input format.
+
+    Args:
+        raw_resource(dict): Old state of resource or existing resource details.
+        scope(str): Specifies whether this is for an Amazon CloudFront distribution or for a regional application.
+        tags(dict): Dict in the format of {tag-key: tag-value}
+
+    Returns:
+        Dict[str, Any]
+    """
+    resource_parameters = OrderedDict(
+        {
+            "Name": "name",
+            "Description": "description",
+            "RegularExpressionList": "regular_expression_list",
+            "Id": "resource_id",
+            "ARN": "arn",
+        }
+    )
+    resource_translated = {"scope": scope, "tags": tags}
+    for parameter_raw, parameter_present in resource_parameters.items():
+        if parameter_raw in raw_resource and raw_resource.get(parameter_raw):
+            resource_translated[parameter_present] = json.loads(
+                json.dumps(raw_resource.get(parameter_raw))
+            )
+
+    return resource_translated
+
+
 async def convert_raw_web_acl_to_present(
     hub,
     ctx,
