@@ -11,6 +11,11 @@ ITERATION_FINISHED = object()
 __func_alias__ = {"exec_": "exec"}
 
 
+def __init__(hub):
+    # A store to re-use existing sessions
+    hub.tool.boto3.client.STORE = {}
+
+
 async def exec_(
     hub,
     ctx,
@@ -31,10 +36,7 @@ async def exec_(
 
     :return: The result of the operation call
     """
-    session: boto3.session.Session = hub.tool.boto3.session.get()
-    client = session.client(
-        service_name=service_name, **hub.tool.boto3.session.kwargs(ctx)
-    )
+    client = hub.tool.boto3.client.get_client(ctx, service_name)
 
     # Don't pass kwargs that have a "None" value to the function call
     kwargs = {k: v for k, v in op_kwargs.items() if v is not None}
@@ -57,10 +59,17 @@ async def exec_(
 
 
 def get_client(hub, ctx, service_name: str):
-    session: boto3.session.Session = hub.tool.boto3.session.get()
-    client = session.client(
-        service_name=service_name, **hub.tool.boto3.session.kwargs(ctx)
-    )
+    kwargs = hub.tool.boto3.session.kwargs(ctx)
+    session_key = hash((service_name, tuple(sorted(kwargs.items()))))
+
+    if session_key not in hub.tool.boto3.client.STORE:
+        session: boto3.session.Session = hub.tool.boto3.session.get()
+        client = session.client(service_name=service_name, **kwargs)
+        hub.tool.boto3.client.STORE[session_key] = client
+    else:
+        # Use existing session
+        client = hub.tool.boto3.client.STORE[session_key]
+
     return client
 
 
@@ -120,10 +129,7 @@ def search(hub, ctx, service_name: str, collection: str, jmes_path: str = "*[]")
     :param jmes_path:
     :return:
     """
-    session: boto3.session.Session = hub.tool.boto3.session.get()
-    client = session.client(
-        service_name=service_name, **hub.tool.boto3.session.kwargs(ctx)
-    )
+    client = hub.tool.boto3.client.get_client(ctx, service_name)
 
     # Find a paginator that can describe this collection
     for operation in client.meta.method_to_api_mapping:
